# Democritus
![Pipeline status](https://gitlab.com/fhightower/democritus/badges/master/build.svg)

Future home of democritus project.

## Usage

Coming soon...

## Credits

This package was created with [Cookiecutter](https://github.com/audreyr/cookiecutter) and Floyd Hightower's [Python project template](https://gitlab.com/fhightower-templates/python-project-template).
